@@ -174,7 +174,6 @@ bool KLineEdit::isClearButtonShown() const
 
 QSize KLineEdit::clearButtonUsedSize() const
 {
-    Q_D(const KLineEdit);
     QSize s;
 
     if (isClearButtonEnabled()) {
@@ -386,35 +385,40 @@ void KLineEditPrivate::setSqueezedText()
     const int fullLength = fullText.length();
     const QFontMetrics fm(q->fontMetrics());
     const int labelWidth = q->size().width() - 2 * q->style()->pixelMetric(QStyle::PM_DefaultFrameWidth) - 2;
-    const int textWidth = fm.width(fullText);
+    const int textWidth = fm.boundingRect(fullText).width();
 
+    // TODO: investigate use of QFontMetrics::elidedText for this
     if (textWidth > labelWidth) {
+        // TODO: better would be "…" char (0x2026), but for that one would need to ensure it's from the main font,
+        // otherwise if resulting in use of a new fallback font this can affect the metrics of the complete text,
+        // resulting in shifted characters
+        const QString ellipsisText = QStringLiteral("...");
         // start with the dots only
-        QString squeezedText = QStringLiteral("...");
-        int squeezedWidth = fm.width(squeezedText);
+        QString squeezedText = ellipsisText;
+        int squeezedWidth = fm.boundingRect(squeezedText).width();
 
         // estimate how many letters we can add to the dots on both sides
         int letters = fullText.length() * (labelWidth - squeezedWidth) / textWidth / 2;
-        squeezedText = fullText.left(letters) + QStringLiteral("...") + fullText.right(letters);
-        squeezedWidth = fm.width(squeezedText);
+        squeezedText = fullText.leftRef(letters) + ellipsisText + fullText.rightRef(letters);
+        squeezedWidth = fm.boundingRect(squeezedText).width();
 
         if (squeezedWidth < labelWidth) {
             // we estimated too short
             // add letters while text < label
             do {
                 letters++;
-                squeezedText = fullText.left(letters) + QStringLiteral("...") + fullText.right(letters);
-                squeezedWidth = fm.width(squeezedText);
+                squeezedText = fullText.leftRef(letters) + ellipsisText + fullText.rightRef(letters);
+                squeezedWidth = fm.boundingRect(squeezedText).width();
             } while (squeezedWidth < labelWidth && letters <= fullLength / 2);
             letters--;
-            squeezedText = fullText.left(letters) + QStringLiteral("...") + fullText.right(letters);
+            squeezedText = fullText.leftRef(letters) + ellipsisText + fullText.rightRef(letters);
         } else if (squeezedWidth > labelWidth) {
             // we estimated too long
             // remove letters while text > label
             do {
                 letters--;
-                squeezedText = fullText.left(letters) + QStringLiteral("...") + fullText.right(letters);
-                squeezedWidth = fm.width(squeezedText);
+                squeezedText = fullText.leftRef(letters) + ellipsisText + fullText.rightRef(letters);
+                squeezedWidth = fm.boundingRect(squeezedText).width();
             } while (squeezedWidth > labelWidth && letters >= 5);
         }
 
@@ -432,7 +436,7 @@ void KLineEditPrivate::setSqueezedText()
     } else {
         q->QLineEdit::setText(fullText);
 
-        q->setToolTip(QLatin1String(""));
+        q->setToolTip(QString());
         QToolTip::showText(q->pos(), QString()); // hide
     }
 
